summaryrefslogtreecommitdiffstats
path: root/akregator/src/feedlistview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/feedlistview.cpp')
-rw-r--r--akregator/src/feedlistview.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/akregator/src/feedlistview.cpp b/akregator/src/feedlistview.cpp
index 117d94c0e..2bb1cbfc0 100644
--- a/akregator/src/feedlistview.cpp
+++ b/akregator/src/feedlistview.cpp
@@ -353,7 +353,7 @@ class NodeListView::CreateItemVisitor : public TreeNodeVisitor
};
NodeListView::NodeListView( TQWidget *parent, const char *name)
- : KListView(parent, name), d(new NodeListViewPrivate)
+ : TDEListView(parent, name), d(new NodeListViewPrivate)
{
d->showTagFolders = true;
d->connectNodeVisitor = new ConnectNodeVisitor(this),
@@ -380,7 +380,7 @@ NodeListView::NodeListView( TQWidget *parent, const char *name)
connect( this, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), this, TQT_SLOT(slotDropped(TQDropEvent*, TQListViewItem*)) );
connect( this, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(slotSelectionChanged(TQListViewItem*)) );
connect( this, TQT_SIGNAL(itemRenamed(TQListViewItem*, int, const TQString&)), this, TQT_SLOT(slotItemRenamed(TQListViewItem*, int, const TQString&)) );
- connect( this, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)), this, TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&)) );
+ connect( this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)) );
connect( &(d->autoopentimer), TQT_SIGNAL( timeout() ), this, TQT_SLOT( openFolder() ) );
clear();
@@ -462,7 +462,7 @@ TreeNodeItem* NodeListView::findNodeItem(TreeNode* node)
TreeNodeItem* NodeListView::findItemByTitle(const TQString& text, int column, ComparisonFlags compare) const
{
- return dynamic_cast<TreeNodeItem*> (KListView::findItem(text, column, compare));
+ return dynamic_cast<TreeNodeItem*> (TDEListView::findItem(text, column, compare));
}
void NodeListView::ensureNodeVisible(TreeNode* node)
@@ -487,7 +487,7 @@ void NodeListView::clear()
d->itemDict.clear();
d->nodeList = 0;
- KListView::clear();
+ TDEListView::clear();
}
void NodeListView::drawContentsOffset( TQPainter * p, int ox, int oy,
@@ -495,7 +495,7 @@ void NodeListView::drawContentsOffset( TQPainter * p, int ox, int oy,
{
bool oldUpdatesEnabled = isUpdatesEnabled();
setUpdatesEnabled(false);
- KListView::drawContentsOffset( p, ox, oy, cx, cy, cw, ch );
+ TDEListView::drawContentsOffset( p, ox, oy, cx, cy, cw, ch );
setUpdatesEnabled(oldUpdatesEnabled);
}
@@ -543,7 +543,7 @@ void NodeListView::movableDropEvent(TQListViewItem* /*parent*/, TQListViewItem*
current->parent()->removeChild(current);
parentNode->insertChild(current, afterMeNode);
- KListView::movableDropEvent(d->parent, d->afterme);
+ TDEListView::movableDropEvent(d->parent, d->afterme);
}
}
@@ -649,8 +649,8 @@ void NodeListView::contentsDragMoveEvent(TQDragMoveEvent* event)
d->autoopentimer.stop();
}
- // the rest is handled by KListView.
- KListView::contentsDragMoveEvent(event);
+ // the rest is handled by TDEListView.
+ TDEListView::contentsDragMoveEvent(event);
}
bool NodeListView::acceptDrag(TQDropEvent *e) const
@@ -876,7 +876,7 @@ void NodeListView::slotItemRenamed(TQListViewItem* item, int col, const TQString
}
}
}
-void NodeListView::slotContextMenu(KListView* list, TQListViewItem* item, const TQPoint& p)
+void NodeListView::slotContextMenu(TDEListView* list, TQListViewItem* item, const TQPoint& p)
{
TreeNodeItem* ti = dynamic_cast<TreeNodeItem*>(item);
emit signalContextMenu(list, ti ? ti->node() : 0, p);
@@ -995,7 +995,7 @@ void NodeListView::slotNodeChanged(TreeNode* node)
TQDragObject *NodeListView::dragObject()
{
KMultipleDrag *md = new KMultipleDrag(viewport());
- TQDragObject *obj = KListView::dragObject();
+ TQDragObject *obj = TDEListView::dragObject();
if (obj) {
md->addDragObject(obj);
}